// java wrapper for vtkHyperTreeGridSource object
//

package vtk;
import vtk.*;

public class vtkHyperTreeGridSource extends vtkHyperTreeGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetMaximumLevel_2();
  public int GetMaximumLevel()
    { return GetMaximumLevel_2(); }

  private native void SetMaximumLevel_3(int id0);
  public void SetMaximumLevel(int id0)
    { SetMaximumLevel_3(id0); }

  private native void SetOrigin_4(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_4(id0,id1,id2); }

  private native void SetOrigin_5(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_5(id0); }

  private native double[] GetOrigin_6();
  public double[] GetOrigin()
    { return GetOrigin_6(); }

  private native void SetGridScale_7(double id0,double id1,double id2);
  public void SetGridScale(double id0,double id1,double id2)
    { SetGridScale_7(id0,id1,id2); }

  private native void SetGridScale_8(double id0[]);
  public void SetGridScale(double id0[])
    { SetGridScale_8(id0); }

  private native double[] GetGridScale_9();
  public double[] GetGridScale()
    { return GetGridScale_9(); }

  private native void SetGridSize_10(int id0,int id1,int id2);
  public void SetGridSize(int id0,int id1,int id2)
    { SetGridSize_10(id0,id1,id2); }

  private native void SetTransposedRootIndexing_11(boolean id0);
  public void SetTransposedRootIndexing(boolean id0)
    { SetTransposedRootIndexing_11(id0); }

  private native boolean GetTransposedRootIndexing_12();
  public boolean GetTransposedRootIndexing()
    { return GetTransposedRootIndexing_12(); }

  private native void SetIndexingModeToKJI_13();
  public void SetIndexingModeToKJI()
    { SetIndexingModeToKJI_13(); }

  private native void SetIndexingModeToIJK_14();
  public void SetIndexingModeToIJK()
    { SetIndexingModeToIJK_14(); }

  private native void SetDimension_15(int id0);
  public void SetDimension(int id0)
    { SetDimension_15(id0); }

  private native int GetDimensionMinValue_16();
  public int GetDimensionMinValue()
    { return GetDimensionMinValue_16(); }

  private native int GetDimensionMaxValue_17();
  public int GetDimensionMaxValue()
    { return GetDimensionMaxValue_17(); }

  private native int GetDimension_18();
  public int GetDimension()
    { return GetDimension_18(); }

  private native void SetOrientation_19(int id0);
  public void SetOrientation(int id0)
    { SetOrientation_19(id0); }

  private native int GetOrientation_20();
  public int GetOrientation()
    { return GetOrientation_20(); }

  private native void SetBranchFactor_21(int id0);
  public void SetBranchFactor(int id0)
    { SetBranchFactor_21(id0); }

  private native int GetBranchFactorMinValue_22();
  public int GetBranchFactorMinValue()
    { return GetBranchFactorMinValue_22(); }

  private native int GetBranchFactorMaxValue_23();
  public int GetBranchFactorMaxValue()
    { return GetBranchFactorMaxValue_23(); }

  private native int GetBranchFactor_24();
  public int GetBranchFactor()
    { return GetBranchFactor_24(); }

  private native void SetUseDescriptor_25(boolean id0);
  public void SetUseDescriptor(boolean id0)
    { SetUseDescriptor_25(id0); }

  private native boolean GetUseDescriptor_26();
  public boolean GetUseDescriptor()
    { return GetUseDescriptor_26(); }

  private native void UseDescriptorOn_27();
  public void UseDescriptorOn()
    { UseDescriptorOn_27(); }

  private native void UseDescriptorOff_28();
  public void UseDescriptorOff()
    { UseDescriptorOff_28(); }

  private native void SetUseMaterialMask_29(boolean id0);
  public void SetUseMaterialMask(boolean id0)
    { SetUseMaterialMask_29(id0); }

  private native boolean GetUseMaterialMask_30();
  public boolean GetUseMaterialMask()
    { return GetUseMaterialMask_30(); }

  private native void UseMaterialMaskOn_31();
  public void UseMaterialMaskOn()
    { UseMaterialMaskOn_31(); }

  private native void UseMaterialMaskOff_32();
  public void UseMaterialMaskOff()
    { UseMaterialMaskOff_32(); }

  private native void SetGenerateInterfaceFields_33(boolean id0);
  public void SetGenerateInterfaceFields(boolean id0)
    { SetGenerateInterfaceFields_33(id0); }

  private native boolean GetGenerateInterfaceFields_34();
  public boolean GetGenerateInterfaceFields()
    { return GetGenerateInterfaceFields_34(); }

  private native void GenerateInterfaceFieldsOn_35();
  public void GenerateInterfaceFieldsOn()
    { GenerateInterfaceFieldsOn_35(); }

  private native void GenerateInterfaceFieldsOff_36();
  public void GenerateInterfaceFieldsOff()
    { GenerateInterfaceFieldsOff_36(); }

  private native void SetDescriptor_37(String id0);
  public void SetDescriptor(String id0)
    { SetDescriptor_37(id0); }

  private native String GetDescriptor_38();
  public String GetDescriptor()
    { return GetDescriptor_38(); }

  private native void SetMaterialMask_39(String id0);
  public void SetMaterialMask(String id0)
    { SetMaterialMask_39(id0); }

  private native String GetMaterialMask_40();
  public String GetMaterialMask()
    { return GetMaterialMask_40(); }

  private native void SetDescriptorBits_41(vtkBitArray id0);
  public void SetDescriptorBits(vtkBitArray id0)
    { SetDescriptorBits_41(id0); }

  private native long GetDescriptorBits_42();
  public vtkBitArray GetDescriptorBits() {
    long temp = GetDescriptorBits_42();

    if (temp == 0) return null;
    return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLevelZeroMaterialIndex_43(vtkIdTypeArray id0);
  public void SetLevelZeroMaterialIndex(vtkIdTypeArray id0)
    { SetLevelZeroMaterialIndex_43(id0); }

  private native void SetMaterialMaskBits_44(vtkBitArray id0);
  public void SetMaterialMaskBits(vtkBitArray id0)
    { SetMaterialMaskBits_44(id0); }

  private native long GetMaterialMaskBits_45();
  public vtkBitArray GetMaterialMaskBits() {
    long temp = GetMaterialMaskBits_45();

    if (temp == 0) return null;
    return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetQuadric_46(vtkQuadric id0);
  public void SetQuadric(vtkQuadric id0)
    { SetQuadric_46(id0); }

  private native long GetQuadric_47();
  public vtkQuadric GetQuadric() {
    long temp = GetQuadric_47();

    if (temp == 0) return null;
    return (vtkQuadric)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetQuadricCoefficients_48(double id0[]);
  public void SetQuadricCoefficients(double id0[])
    { SetQuadricCoefficients_48(id0); }

  private native void GetQuadricCoefficients_49(double id0[]);
  public void GetQuadricCoefficients(double id0[])
    { GetQuadricCoefficients_49(id0); }

  private native int GetMTime_50();
  public int GetMTime()
    { return GetMTime_50(); }

  private native long ConvertDescriptorStringToBitArray_51(String id0);
  public vtkBitArray ConvertDescriptorStringToBitArray(String id0) {
    long temp = ConvertDescriptorStringToBitArray_51(id0);

    if (temp == 0) return null;
    return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long ConvertMaterialMaskStringToBitArray_52(String id0);
  public vtkBitArray ConvertMaterialMaskStringToBitArray(String id0) {
    long temp = ConvertMaterialMaskStringToBitArray_52(id0);

    if (temp == 0) return null;
    return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkHyperTreeGridSource() { super(); }

  public vtkHyperTreeGridSource(long id) { super(id); }
  public native long   VTKInit();

}
